@@ -53,7 +53,7 @@ MICA.ContCont <- function(Trial.R, D.aa, D.bb, T0S0, T1S1, T0T0=1, T1T1=1, S0S0=
         rownames(Results) <- NULL}
     }
   }
-  Results <- data.frame(Results)
+  Results <- data.frame(Results, stringsAsFactors = TRUE)
   rownames(Results) <- NULL
   Total.Num.Matrices <- nrow(combins)
   
